@@ -27,11 +27,13 @@ class FFile:
 		if self.__file_exists():
 			with open(self.nomeFile, 'r') as fr:
 				self._string = fr.read()
+			
 
 	def read_json(self) -> None:
 		"""Legge il JSON e lo decodifica"""
 		if self.__file_exists():
-			self._json = json.loads(self.read_file())
+			self.read_file()
+			self._json = json.loads(self._string)
 
 	def create_file(self, content, override=True) -> None:
 		"""Scrive un nuovo file"""
@@ -46,9 +48,4 @@ class FFile:
 		"""Aggiungi alla fine del file il contenuto"""
 		if self.__file_exists():
 			with open(self.nomeFile, "a") as fa:
-				fa.write(content)
-
-
-def main():
-	NomeFile = input("Nome del file: ")
-	F = File(NomeFile)
\ No newline at end of file
+				fa.write(content)
\ No newline at end of file
